log using cpsmaster.log, replace

/************************************************/
/* Creating Master Dataset from March CPS 		*/
/* Coile, Duggan, Guo							*/
/* January 10, 2015								*/
/************************************************/
clear all
set more off

/************************************************/
/* Extracting data from March CPS 1980-2014     */
/************************************************/

//1980-1987
forval x=80/87 {
use cpsmar19`x', clear
keep hhidnum mis age sex ethnicit highgrad gradecom race besr vet bweight rpovll ditm24d9  i53dvp kststate recodind rwemind
gen year=19`x'
rename mis h_mis
rename age a_age
rename sex a_sex
rename highgrad a_hga
rename gradecom a_hgc
rename rpovll povll
rename kststate mststate
rename ditm24d9 disability
rename  i53dvp vet_yn
save cpsmar`x', replace
}
//1988-1991
forval x=88/91 {
use /homes/data/cps/cpsmar19`x', clear
keep h_idnum h_mis a_age a_sex a_hga a_hgc a_race a_reorgn a_lfsr a_vet a_fnlwgt p_stat povll dis_hp vet* hg_st60 grin_st a_dtind a_mjind
rename grin_st mig_st
gen year=19`x'
save cpsmar`x', replace
}
//1992-1993
forval x=92/93 {
use /homes/data/cps/cpsmar19`x', clear
keep h_idnum h_mis a_age a_sex a_hga a_race a_reorgn a_lfsr a_vet a_fnlwgt p_stat povll dis_hp vet* hg_st60 grin_st a_dtind a_mjind
rename grin_st mig_st
gen year=19`x'
save cpsmar`x', replace
}

//1994
use /homes/data/cps/cpsmar1994, clear
keep h_idnum h_mis a_age a_sex a_hga a_race a_reorgn a_lfsr pemlr a_vet a_fnlwgt p_stat povll dis_hp vet* hg_st60 grin_st a_dtind a_mjind
rename grin_st mig_st
gen year=1994
save cpsmar94, replace

//1995
use /homes/data/cps/cpsmar1995, clear
keep h_idnum h_mis peage a_sex a_hga a_race a_reorgn a_lfsr a_vet a_fnlwgt p_stat povll dis_hp vet* hg_st60 grin_st a_dtind a_mjind
rename peage a_age
rename grin_st mig_st
gen year=1995
save cpsmar95, replace

//1996-1999
forval x=96/99 {
use /homes/data/cps/cpsmar19`x', clear
keep h_idnum h_mis a_age a_sex a_hga a_race a_reorgn hea a_lfsr a_vet a_fnlwgt p_stat povll dis_hp vet* hg_st60 geco mig_st a_dtind a_mjind
gen year=19`x'
save cpsmar`x', replace
}
//2000-2002
use /homes/data/cps/cpsmar2000, clear
keep h_idnum h_mis a_age a_sex a_hga a_race a_reorgn hea a_lfsr a_vet a_fnlwgt p_stat povll dis_hp vet* hg_st60 geco mig_st a_dtind a_mjind
gen year=2000
save cpsmar00, replace

use /homes/data/cps/cpsmar2001, clear
keep h_idnum h_mis a_age a_sex a_hga a_race a_reorgn hea a_lfsr a_vet a_fnlwgt p_stat povll dis_hp vet* gestfips geco mig_st a_dtind a_mjind
gen year=2001
save cpsmar01, replace

use /homes/data/cps/cpsmar2002, clear
keep h_idnum h_mis a_age a_sex a_hga a_race a_reorgn hea a_lfsr a_vet a_fnlwgt marsupwt p_stat povll dis_hp vet* gestfips geco mig_st a_dtind a_mjind
gen year=2002
save cpsmar02, replace

//2003-2004
forval x=3/4 {
use /homes/data/cps/cpsmar200`x', clear
keep h_idnum h_mis a_age a_sex a_hga prdtrace pehspnon hea a_lfsr a_vet a_fnlwgt marsupwt p_stat povll dis_hp vet* gestfips geco mig_st a_dtind a_mjind
gen year=200`x'
save cpsmar0`x', replace
}

// 2005 
use /homes/data/cps/cpsmar2005, clear
keep h_idnum1 h_mis a_age a_sex a_hga prdtrace pehspnon hea a_lfsr a_vet a_fnlwgt marsupwt p_stat povll dis_hp vet* gestfips gtco mig_st a_dtind a_mjind
rename h_idnum1 h_idnum
rename gtco geco
gen year=2005
save cpsmar05, replace

// 2006-2009
forval x=6/9 {
use /homes/data/cps/cpsmar200`x', clear
keep h_idnum1 h_mis a_age a_sex a_hga prdtrace pehspnon hea a_lfsr peafever peafwhn* a_fnlwgt marsupwt p_stat povll dis_hp vet* gestfips gtco mig_st a_dtind a_mjind
rename h_idnum1 h_idnum
rename gtco geco
gen year=200`x'
save cpsmar0`x', replace
}
// 2010-2014
forval x=10/14 {
use /homes/data/cps/cpsmar20`x', clear
keep h_idnum1 h_mis a_age a_sex a_hga prdtrace pehspnon hea a_lfsr peafever peafwhn* a_fnlwgt marsupwt p_stat povll dis_hp vet* gestfips gtco mig_st a_dtind a_mjind
rename h_idnum1 h_idnum
rename gtco geco
gen year=20`x'
save cpsmar`x', replace
}

//Appending into Master Dataset
forval x=80/99 {
	append using cpsmar`x'
}
forval x=0/9 {
	append using cpsmar0`x'
}
forval x=10/13 {
	append using cpsmar`x'
}

/************************************************/
/* Standardizing Variables Across Years	        */
/************************************************/
destring h_idnum, replace
replace hhidnum=h_idnum if hhidnum==.
drop h_idnum
sort hhidnum year h_mis
order hhidnum year h_mis
replace a_fnlwgt=bweight if a_fnlwgt==.
drop bweight
drop vet_qva

//Education Variable
replace a_hga=0 if a_hga==31
replace a_hga=32 if a_hga==1 | a_hga==2 | a_hga==3 | a_hga==4 
replace a_hga=33 if a_hga==5 | a_hga==6
replace a_hga=34 if a_hga==7 | a_hga==8
replace a_hga=35 if a_hga==9
replace a_hga=36 if a_hga==10
replace a_hga=37 if a_hga==11
replace a_hga=38 if a_hga==12 & a_hgc==2
replace a_hga=39 if a_hga==12 & a_hgc==1
replace a_hga=40 if a_hga==13 | a_hga==14 | a_hga==15 | a_hga==41 | a_hga==42
replace a_hga=40 if a_hga==16 & a_hgc==2
replace a_hga=43 if a_hga==16 & a_hgc==1
replace a_hga=43 if a_hga==17
replace a_hga=50 if a_hga==18 | a_hga==19 | a_hga==44 | a_hga==45 | a_hga==46
drop a_hgc

//Hispanic Variable
gen hispanic=1 if ethnicit<30
replace hispanic=1 if a_reorgn<8
replace hispanic=1 if pehspnon==1
replace hispanic=0 if hispanic==.
drop ethnicit a_reorgn pehspnon

//Race Variable
**Black
gen black=1 if race==2
replace black=1 if a_race==2 
replace black=1 if prdtrace==2
replace black=0.5 if prdtrace==6 | prdtrace==10 | prdtrace==11 | prdtrace==12
replace black=0 if black==.

**Other
gen other=1 if race==3
replace other=1 if a_race==3 | a_race==4 | a_race==5 
replace other=1 if prdtrace==3 | prdtrace==4 | prdtrace==5
replace other=0.5 if prdtrace==7 | prdtrace==8 | prdtrace==9 | prdtrace==10 | prdtrace==11 | prdtrace==12
replace other=1 if prdtrace>12 & prdtrace!=.
replace other=0 if other==.

//Standardizing Service Variable prior to 2006
replace a_vet=vet if year<1988
drop vet
gen vet=1 if a_vet<6
replace vet=1 if peafever==1
replace vet=0 if vet==.

//Labor Force Participation
gen inlf=1 if a_lfsr==1 | a_lfsr==2 | a_lfsr==3 | a_lfsr==4
replace inlf = 1 if pemlr>=1 & pemlr<=4 & year==1994
replace inlf=1 if besr==1 | besr==2 | besr==3
replace inlf=0 if inlf==.

//State Variable
replace hg_st60=mststate if hg_st60==.
replace gestfips=6 if hg_st60==93 //CA
replace gestfips=36 if hg_st60==21 //NY
replace gestfips=48 if hg_st60==74 //TX
replace gestfips=42 if hg_st60==23 //PA
replace gestfips=17 if hg_st60==33 //IL
replace gestfips=39 if hg_st60==31 //OH
replace gestfips=12 if hg_st60==59 //FL
replace gestfips=26 if hg_st60==34 //MI
replace gestfips=34 if hg_st60==22 //NJ
replace gestfips=37 if hg_st60==56 //NC
replace gestfips=25 if hg_st60==14 //MA
replace gestfips=18 if hg_st60==32 //IN
replace gestfips=13 if hg_st60==58 //GA
replace gestfips=51 if hg_st60==54 //VA
replace gestfips=29 if hg_st60==43 //MO
replace gestfips=55 if hg_st60==35 //WI
replace gestfips=47 if hg_st60==62 //TN
replace gestfips=24 if hg_st60==52 //MD
replace gestfips=22 if hg_st60==72 //LA
replace gestfips=53 if hg_st60==91 //WA
replace gestfips=27 if hg_st60==41 //MN
replace gestfips=1 if hg_st60==63 //AL
replace gestfips=21 if hg_st60==61 //KY
replace gestfips=45 if hg_st60==57 //SC
replace gestfips=09 if hg_st60==16 //CT
replace gestfips=40 if hg_st60==73 //OK
replace gestfips=19 if hg_st60==42 //IA
replace gestfips=8 if hg_st60==84 //CO
replace gestfips=4 if hg_st60==86 //AZ
replace gestfips=41 if hg_st60==92 //OR
replace gestfips=28 if hg_st60==64 //MS
replace gestfips=20 if hg_st60==47 //KS
replace gestfips=5 if hg_st60==71 //AR
replace gestfips=54 if hg_st60==55 //WV
replace gestfips=31 if hg_st60==46 //NE
replace gestfips=49 if hg_st60==87 //UT
replace gestfips=35 if hg_st60==85 //NM
replace gestfips=23 if hg_st60==11 //ME
replace gestfips=15 if hg_st60==95 //HI
replace gestfips=44 if hg_st60==15 //RI
replace gestfips=16 if hg_st60==82 //ID
replace gestfips=33 if hg_st60==12 //NH
replace gestfips=32 if hg_st60==88 //NV
replace gestfips=30 if hg_st60==81 //MT
replace gestfips=46 if hg_st60==45 //SD
replace gestfips=38 if hg_st60==44 //ND
replace gestfips=11 if hg_st60==53 //DC
replace gestfips=10 if hg_st60==51 //DE
replace gestfips=50 if hg_st60==13 //VT
replace gestfips=56 if hg_st60==83 //WY
replace gestfips=2 if hg_st60==94 //AK
drop mststate hg_st60

/************************************************/
/* Adding State/County Unemployment Data        */
/************************************************/
rename gestfips state
rename geco county
replace county=0 if county==.
replace county=86 if county==25 & state==12 //Rename Dade -> Miami-Dade

sort state year
merge m:1 state year using state80s //State unemployment data for 1980's
drop _merge

sort state county year
merge m:1 state county year using county90t13, update // County unemployment data from 1990-2013
drop _merge

merge m:1 state year using state90t13, update //State unemployment data for 1990-2013
drop _merge

merge m:1 state year using state14, update //State unemployment data for 2014
drop _merge

drop if a_sex==. //Get rid of empty using data

save cpstemp,replace

//Merge in year t-1
use state80s, clear
replace year=year+1
rename stlaborforce stlaborforce_1
rename stunemployed stunemployed_1
rename stunemploymentrate stunemploymentrate_1
rename population16 population16_1
save state80s_1, replace

use county90t13, clear
replace year=year+1
rename laborforce laborforce_1
rename unemployed unemployed_1
rename unemploymentrate unemploymentrate_1
rename cntypop16 cntypop16_1
rename cntypop cntypop_1
save county90t13_1, replace

use state90t13,clear
replace year=year+1
rename stlaborforce stlaborforce_1
rename stunemployed stunemployed_1
rename stunemploymentrate stunemploymentrate_1
rename population16 population16_1
rename population population_1
save state90t13_1, replace

use cpstemp, clear
sort state year
merge m:1 state year using state80s_1
drop _merge

sort state county year
merge m:1 state county year using county90t13_1, update
drop _merge

merge m:1 state year using state90t13_1, update
drop _merge

drop if a_sex==. //Get rid of empty using data
save cpstemp,replace

/****************************************************/
/* Generating Unemployment Data for Missing Counties*/
/****************************************************/
do missingcounties.do

clear all
use cpstemp, clear

merge m:1 state county year using missunempl.dta, update
drop _merge
merge m:1 state county year using missunempl_1.dta, update
drop _merge

replace unemploymentrate = notid_ur if unemploymentrate==.
replace unemploymentrate_1 = notid_ur_1 if unemploymentrate_1==.

tostring(state),replace
replace fips=state+"999" if fips==""

/************************************************/
/* Formatting for Regression Analysis   */
/************************************************/

//Drop females
keep if a_sex==1

//Age dummies
keep if a_age>=25 & a_age<=74
tab a_age, gen(ageDV)

//Year dummies
tab year, gen(yearDV)

//Year x State dummies
tab state, gen(stateDV)
forval x=1/50 {
forval y=1/35 {
gen year`y'state`x' = yearDV`y'*stateDV`x'
}
} 

tostring(year),replace
gen fipsyear = fips+year
destring(year),replace

//State x Vet dummies
forval x=1/51 {
gen statevet`x' = stateDV`x'*vet
gen statenovet`x' = stateDV`x' if vet==0
replace statenovet`x' = 0 if statenovet`x'==.
}

//County x Vet dummies
tab fips, gen(fipsDV)
forval x=1/380 {
gen fipsvet`x' = fipsDV`x'*vet
gen fipsnovet`x' = fipsDV`x' if vet==0
replace fipsnovet`x' = 0 if fipsnovet`x'==.
}

//Demeaning by Average National Unemployment Rate
gen demeanedur = unemploymentrate - 6.45
gen demeanedstur = stunemploymentrate - 6.45
gen demeanedur_1 = unemploymentrate_1 - 6.42
gen demeanedstur_1 = stunemploymentrate_1 - 6.42

save cpsmaster.dta, replace

log close
